### Needle.sh simplifies security for web applications

Secure your web applications in a few lines of code with Needle.sh SDK for Python. 
This version supports Django web framework. 

Visit [Needle.sh website](https://needle.sh/) for more details.

#### Installation
* Install the Needle.sh SDK for Python

        pip install needle-sdk

* Create a web app in your Needle.sh account and follow the instructions. Visit [Needle.sh website](https://needle.sh/) for more details.

#### Python support
This SDK works for Python versions 3.0 and higher

#### License
Needle.sh is proprietary software.